==> Blind-src-V2.45.0.2.zip: Blind-2.45/cmds/w.c <==
static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/cmds/RCS/w.c,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $";

/*
 *
 * $Log: w.c,v $
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * *** empty log message ***
 *
 * Revision 2.43  1995/03/20  01:43:09  zeus
 *
 */

#define NOTIMEB
 
#include "../protos/common.h"
#include "../protos/prototypes.h"
#include "../protos/enterturn-g.h"
#include "../protos/cmds.h"
#include "../protos/cmds-g.h"

extern char tbuf[];
extern int pos;
extern player *players;
extern char err_tmp[];

void w_cmd_rcsid (void);
void
w_cmd_rcsid (void)
{
  printf ("%s\n",rcsid);
}


void
w_cmd (char *buf, player * P)
{
  player *P2;
  alliance *a, *a2;
  defensive *d, *d2;

  hcstrcpy (tbuf, buf);
  pos = 0;
  (void) next_token ();
  P2 = ninputplayer ();
  if (P2)
    if (P2 == P)
    {
      for (P2 = players; P2; P2 = P2->next)
	if (P2 != P)
	{
	  for (a = P->allies; a; a=a2)
          {
            a2 = a->next;
	    if (a->ally == P2)
	    {
	      removelist (&P->allies, a);
	      break;
	    }
	  }
	  for (d = P->defend; d; d=d2)
	  {
	    d2 = d->next;
	    if (d->defend == P2)
	    {
	      removelist (&P->defend, d);
	      break;
	    }
	  }
	}			/* end of inner "if not self" test */
    }				/* end of outer "if not self" test */
    else
    {
      for (a = P->allies; a; a = a2)
      {
        a2 = a->next;
	if (a->ally == P2)
	{
	  removelist (&P->allies, a);
	  break;
	}
      }
      for (d = P->defend; d; d=d2)
      {
        d2 = d->next;
	if (d->defend == P2)
	{
	  removelist (&P->defend, d);
	  break;
	}
      }
    }
  else
  {
    error (err_tmp);
    return;
  }
  extra_token ();
}

==> Blind-src-V2.46.0.1.zip: Blind-2.46/cmds/w.c <==
static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.46/cmds/RCS/w.c,v 2.46 1997/04/18 12:13:56 zeus Exp zeus $";

/*
 *
 * $Log: w.c,v $
 * Revision 2.46  1997/04/18 12:13:56  zeus
 * *** empty log message ***
 *
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * Revision 2.43  1995/03/20  01:43:09  zeus
 *
 */

#define NOTIMEB
 
#include "common.h"
#include "prototypes.h"
#include "enterturn-g.h"
#include "cmds.h"
#include "cmds-g.h"

extern player *players;
extern char err_tmp[];

void w_cmd_rcsid (void);

void
w_cmd_rcsid (void)
{
  printf ("%s\n",rcsid);
}


void
w_cmd (char *buf, player * P)
{
  player *P2;
  alliance *a, *a2;
  defensive *d, *d2;

  cmd_init(buf);
  P2 = ninputplayer ();
  if (P2)
    if (P2 == P)
    {
      for (P2 = players; P2; P2 = P2->next)
	if (P2 != P)
	{
	  for (a = P->allies; a; a=a2)
          {
            a2 = a->next;
	    if (a->ally == P2)
	    {
	      removelist (&P->allies, a);
	      break;
	    }
	  }
	  for (d = P->defend; d; d=d2)
	  {
	    d2 = d->next;
	    if (d->defend == P2)
	    {
	      removelist (&P->defend, d);
	      break;
	    }
	  }
	}			/* end of inner "if not self" test */
    }				/* end of outer "if not self" test */
    else
    {
      for (a = P->allies; a; a = a2)
      {
        a2 = a->next;
	if (a->ally == P2)
	{
	  removelist (&P->allies, a);
	  break;
	}
      }
      for (d = P->defend; d; d=d2)
      {
        d2 = d->next;
	if (d->defend == P2)
	{
	  removelist (&P->defend, d);
	  break;
	}
      }
    }
  else
  {
    error (err_tmp);
    return;
  }
  extra_token ();
}
